/**
 * Represents an inventory object
 */
export class Inventory {
    /**
     * Create an inventory item
     *
     * Usage:
     *
     * ```
     * var req = Inventory.create(inventory);
     * client.send(req).then(inventory => console.log(inventory));
     * ```
     * @param {Inventory|Inventory[]} resource The inventory item to update
     * @return {BricklinkRequest} A request that resolves to a single {@link Inventory} or undefined if multiple.
     */
    static create(resource: Inventory | Inventory[]): BricklinkRequest;
    /**
     * Method to get specific inventory resource
     *
     * Usage:
     *
     * ```
     * var req = Inventory.get(10);
     * client.send(req).then(inventory => console.log(inventory));
     * ```
     *
     * @param {number} inventoryId An inventory id.
     * @return {BricklinkRequest} A request that resolves to an {@link Inventory} instance.
     */
    static get(inventoryId: number): BricklinkRequest;
    /**
     * Get a list of all inventory
     *
     * Usage:
     *
     * ```
     * var req = Inventory.all();
     * client.send(req).then(inventories => console.log(inventories));
     * ```
     *
     * @return {BricklinkRequest} A request that resolves to an array of {@link Inventory}.
     */
    static all(): BricklinkRequest;
    /**
     * Update an inventory item
     *
     * Usage:
     *
     * ```
     * var req = Inventory.update(inventory);
     * client.send(req).then(inventory => console.log(inventory));
     * ```
     * @param {Inventory} resource The inventory item to update
     * @param {number} quantityChange The difference of quantity to apply
     * @return {BricklinkRequest} A request that resolves to an {@link Inventory}.
     */
    static update(resource: Inventory, quantityChange?: number): BricklinkRequest;
    /**
     * Delete an inventory item
     *
     * Usage:
     *
     * ```
     * var req = Inventory.delete(inventory_id);
     * client.send(req).then(inventory => console.log(inventory));
     * ```
     * @param {string} inventory_id The inventory item to update
     * @return {BricklinkRequest} A request that resolves if successfully deleted
     */
    static delete(inventory_id: string): BricklinkRequest;
    /**
     * Create a new instance of a store inventory
     * @param {object} [data] API response data.
     * @param {number} [data.inventory_id] The inventory id. i.e. - 50592684
     * @param {object} [data.item] The inventory item.
     * @param {string} [data.item.no] The inventory item id. i.e. - bel004
     * @param {string} [data.item.name] The inventory item name. i.e. - Belville Accessories - Complete Sprue - Perfume Bottles (same as 6932)
     * @param {string} [data.item.type] The inventory item type. i.e. - MINIFIG, PART, SET, BOOK, GEAR, CATALOG, INSTRUCTION, UNSORTED_LOT, ORIGINAL_BOX
     * @param {string} [data.item.categoryID] The inventory item type. i.e. - PART
     * @param {number} [data.color_id] The inventory item color id. i.e. - 5
     * @param {number} [data.quantity] The number of items included in this inventory. i.e. - 10
     * @param {string} [data.new_or_used] Whether the inventory item is new or used. i.e. - U or N
     * @param {string} [data.completeness] Whether the inventory set is complete or incomplete. i.e. - C, B or S
     * @param {string} [data.unit_price] 	The original price of this item per sale unit
     * @param {number} [data.bind_id] The ID of the parent lot that this lot is bound to
     * @param {string} [data.description] A short description for this inventory
     * @param {string} [data.remarks] User remarks on this inventory
     * @param {number} [data.bulk] Buyers can buy this item only in multiples of the bulk amount
     * @param {boolean} [data.is_retain] Whether the item retains in inventory after it is sold out
     * @param {boolean} [data.is_stock_room] Whether the inventory item appears only in the owner's inventory. ie. - true
     * @param {string} [data.stock_room_id] The inventory stockroom identifier. i.e. - A, B or C
     * @param {string|Date} [data.date_created]
     * @param {number} [data.sale_rate]
     * @param {string} [data.my_cost]
     * @param {number} [data.tier_quantity1]
     * @param {string} [data.tier_price1]
     * @param {number} [data.tier_quantity2]
     * @param {string} [data.tier_price2]
     * @param {number} [data.tier_quantity3]
     * @param {string} [data.tier_price3]
     */
    constructor(data?: {
        inventory_id?: number;
        item?: {
            no?: string;
            name?: string;
            type?: string;
            categoryID?: string;
        };
        color_id?: number;
        quantity?: number;
        new_or_used?: string;
        completeness?: string;
        unit_price?: string;
        bind_id?: number;
        description?: string;
        remarks?: string;
        bulk?: number;
        is_retain?: boolean;
        is_stock_room?: boolean;
        stock_room_id?: string;
        date_created?: string | Date;
        sale_rate?: number;
        my_cost?: string;
        tier_quantity1?: number;
        tier_price1?: string;
        tier_quantity2?: number;
        tier_price2?: string;
        tier_quantity3?: number;
        tier_price3?: string;
    });
    /** @type {number} */
    inventory_id: number;
    /** @type {object} */
    item: object;
    /** @type {number} */
    color_id: number;
    /** @type {number} */
    quantity: number;
    /** @type {string} */
    new_or_used: string;
    /** @type {string} */
    completeness: string;
    /** @type {string} */
    unit_price: string;
    /** @type {number} */
    bind_id: number;
    /** @type {string} */
    description: string;
    /** @type {string} */
    remarks: string;
    /** @type {number} */
    bulk: number;
    /** @type {boolean} */
    is_retain: boolean;
    /** @type {boolean} */
    is_stock_room: boolean;
    /** @type {string} */
    stock_room_id: string;
    /** @type {Date} */
    date_created: Date;
    /** @type {number} */
    sale_rate: number;
    /** @type {string} */
    my_cost: string;
    /** @type {number} */
    tier_quantity1: number;
    /** @type {string} */
    tier_price1: string;
    /** @type {number} */
    tier_quantity2: number;
    /** @type {string} */
    tier_price2: string;
    /** @type {number} */
    tier_quantity3: number;
    /** @type {string} */
    tier_price3: string;
}
import { BricklinkRequest } from '../request';
